@@ -12,7 +12,7 @@ def _touch(fname):
 def _build(path, pwd=None):
     current = path.pop(0)
     if pwd:
-        here = pwd + os.sep + current
+        here = os.path.join(pwd, current)
     else:
         here = current
     if not path:
@@ -23,25 +23,25 @@ def _build(path, pwd=None):
         _build(path, here)
 
 
-def generate_view(dir, name):
-    view = "app" + os.sep + "views" + os.sep + name + ".html"
+def generate_view(directory, name):
+    view = os.path.join("app", "views", name + ".html")
     split = name.split(os.sep)
     namespace = split[-1]
     split[-1] = "_" + namespace + ".scss"
-    style = "lib" + os.sep + "styles" + os.sep + "site" + os.sep + os.sep.join(split)
-    _build(view.split(os.sep), dir)
-    _build(style.split(os.sep), dir)
+    style = os.path.join("lib", "styles", "site", os.sep.join(split))
+    _build(view.split(os.sep), directory)
+    _build(style.split(os.sep), directory)
 
     # view html file
-    with open(dir + os.sep + view, 'w') as f:
+    with open(os.path.join(directory, view), 'w') as f:
         f.write("<div class='page %s'>\n\n</div>" % namespace)
 
     # styles file
-    with open(dir + os.sep + style, 'w') as f:
+    with open(os.path.join(directory, style), 'w') as f:
         f.write(".page.%s{\n\n}" % namespace)
 
     #import styles styles
-    with open(dir + os.sep + 'lib' + os.sep + 'styles' + os.sep + 'styles.scss', 'a') as styles:
+    with open(os.path.join(directory, 'lib', 'styles', 'styles.scss'), 'a') as styles:
         styles.write('@import "site/%s";\n' % name)
 
 
